@@ -262,7 +262,7 @@ if __name__ == "__main__":
         eps = 0.10
         # noinspection PyTupleAssignmentBalance
         gen_M, _, _, _ = rng.generate_nmf_reconstruction(n_comp=nb_clusters, n_feat=h_size, n_obs=w_size,
-                                                         h_icorr_min=min_corr, h_icorr_max=max_corr,
+                                                         h_icorr_min=min_corr, h_xcorr_max=max_corr,
                                                          random_norms=rnd_norms, epsilon=eps)
         imp_nmf_proxy = imp.Imputer(method="nmf.proxy",
                                     params={"ncomp": 3,
@@ -317,7 +317,7 @@ if __name__ == "__main__":
                                [[0, 0], [1, 2]]]
         gen_m, gen_w, gen_h, gen_noise = rng.generate_nmf_reconstruction(n_comp=nb_clusters, n_feat=h_size,
                                                                          n_obs=w_size, h_icorr_min=min_corr,
-                                                                         h_icorr_max=max_corr,
+                                                                         h_xcorr_max=max_corr,
                                                                          random_norms=random_norms, epsilon=eps,
                                                                          avg_w_clust=wclust_factor)
         for censor_indices in censor_indices_list:
@@ -375,7 +375,7 @@ if __name__ == "__main__":
                           f"corrmax{round(max_corr, 2)}_noise{round(eps, 2)}_{rnstr}_mis{censor_rate}.csv"
                 gen_M, gen_w, gen_h, _ = rng.generate_nmf_reconstruction(n_comp=nb_clusters, n_feat=h_size,
                                                                          n_obs=w_size, h_icorr_min=min_corr,
-                                                                         h_icorr_max=max_corr,
+                                                                         h_xcorr_max=max_corr,
                                                                          random_norms=random_norms, epsilon=eps)
 
             utl.censor_data(mat=gen_M, p=censor_rate, inplace=True)
